@@ -19,6 +19,7 @@ from tempfile import mkdtemp
 
 import osgeo.gdal as gdal
 import ogr, osr
+import numpy as np
 
 KEEP_FILENAME = ".tondor_keep"
 
@@ -80,6 +81,14 @@ def generate_yearmonths(ym_from, ym_till):
 
 #################################################################################################
 #################################################################################################
+def yearmonth_parse(yearmonth):
+    start_final_date = [ym.strip() for ym in yearmonth.split("-")]
+    start_date = datetime.strptime(start_final_date[0],"%Y%m%d")
+    final_date   = datetime.strptime(start_final_date[1],"%Y%m%d")
+    start_date_basename = start_date.strftime("%Y%m%d")
+    final_date_basename = final_date.strftime("%Y%m%d")
+    return yearmonth, start_date, final_date, start_date_basename, final_date_basename
+
 def generate_timeperiod_monthly(year, month):
     year = int(year)
     month = int(month)
